@@ -7,9 +7,8 @@ use 5.010001;
 
 use List::MoreUtils qw( any );
 
-use Term::Choose            qw();
-use Term::Choose::Constants qw( :screen );
-use Term::Form              qw();
+use Term::Choose qw();
+use Term::Form   qw();
 
 use App::DBBrowser::Auxil;
 use App::DBBrowser::Table::Extensions;
@@ -41,7 +40,7 @@ sub build_having_col {
         $aggr =~ s/\(\S\)\z//;
         $sql->{having_stmt} .= ' ' . $aggr . "(";
         $quote_aggr          =       $aggr . "(";
-        my $tc = Term::Choose->new( $sf->{i}{default} );
+        my $tc = Term::Choose->new( $sf->{i}{tc_default} );
         my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
         $ax->print_sql( $sql );
         # Choose
@@ -62,8 +61,7 @@ sub build_having_col {
 sub add_operator_with_value {
     my ( $sf, $sql, $clause, $quote_col ) = @_;
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
-    my $tc = Term::Choose->new( $sf->{i}{default} );
-    #my $tf = Term::Form->new();
+    my $tc = Term::Choose->new( $sf->{i}{tc_default} );
     my $stmt = $clause . '_stmt';
     my $args = $clause . '_args';
     my $sign_idx = $sf->{o}{enable}{'expand_' . $clause};
@@ -166,7 +164,7 @@ sub add_operator_with_value {
 sub __col_op {
     my ( $sf, $sql, $op, $stmt ) = @_;
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
-    my $tc = Term::Choose->new( $sf->{i}{default} );
+    my $tc = Term::Choose->new( $sf->{i}{tc_default} );
     my $arg;
     if ( $op =~ /^(.+)\s(%?col%?)\z/ ) {
         $op = $1;
@@ -252,10 +250,9 @@ sub __regex_op {
     $sql->{$stmt} .= $regex_op;
     push @{$sql->{$args}}, '...';
     $ax->print_sql( $sql );
-    my $tf = Term::Form->new();
+    my $tf = Term::Form->new( $sf->{i}{tf_default} );
     # Readline
     my $value = $tf->readline( 'Pattern: ' );
-    print HIDE_CURSOR;
     if ( ! defined $value ) {
         return;
     }
@@ -269,7 +266,7 @@ sub __regex_op {
 sub __in_op {
     my ( $sf, $sql, $op, $stmt, $args, $ext_col ) = @_;
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
-    my $tf = Term::Form->new();
+    my $tf = Term::Form->new( $sf->{i}{tf_default} );
     $sql->{$stmt} .= ' ' . $op;
     if ( $ext_col ) {                           #
         $ext_col =~ s/^\s*\(|\)\s*\z//g;        #
@@ -283,7 +280,6 @@ sub __in_op {
         $ax->print_sql( $sql );
         # Readline
         my $value = $tf->readline( 'Value: ' );
-        print HIDE_CURSOR;
         if ( ! defined $value ) {
             return;
         }
@@ -304,7 +300,7 @@ sub __in_op {
 sub __between_op {
     my ( $sf, $sql, $op, $stmt, $args ) = @_;
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
-    my $tf = Term::Form->new();
+    my $tf = Term::Form->new( $sf->{i}{tf_default} );
     $sql->{$stmt} .= ' ' . $op;
     #if ( $ext_col ) {                       #
     #    $sql->{$stmt} .= ' ' . $ext_col;    #
@@ -313,7 +309,6 @@ sub __between_op {
     $ax->print_sql( $sql );
     # Readline
     my $value_1 = $tf->readline( 'Value 1: ' );
-    print HIDE_CURSOR;
     if ( ! defined $value_1 ) {
         return;
     }
@@ -322,7 +317,6 @@ sub __between_op {
     $ax->print_sql( $sql );
     # Readline
     my $value_2 = $tf->readline( 'Value 2: ' );
-    print HIDE_CURSOR;
     if ( ! defined $value_2 ) {
         return;
     }
@@ -335,7 +329,7 @@ sub __between_op {
 sub __default_op {
     my ( $sf, $sql, $op, $stmt, $args, $ext_col ) = @_;
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
-    my $tf = Term::Form->new();
+    my $tf = Term::Form->new( $sf->{i}{tf_default} );
     $sql->{$stmt} .= ' ' . $op;
     if ( $ext_col ) {                       #
         $sql->{$stmt} .= ' ' . $ext_col;    #
@@ -345,7 +339,6 @@ sub __default_op {
     my $prompt = $op =~ /^(?:NOT\s)?LIKE\z/ ? 'Pattern: ' : 'Value: '; #
     # Readline
     my $value = $tf->readline( $prompt );
-    print HIDE_CURSOR;
     if ( ! defined $value ) {
         return;
     }
